[Bf-blender-cvs] SVN commit: /data/svn/bf-blender [54774] trunk/blender/source/gameengine/ Rasterizer: code cleanup: bge - was converting float[] to MT_Vector' s just to compare.

Campbell Barton ideasman42 at gmail.com
Sat Feb 23 02:57:57 CET 2013


Revision: 54774
          http://projects.blender.org/scm/viewvc.php?view=rev&root=bf-blender&revision=54774
Author:   campbellbarton
Date:     2013-02-23 01:57:56 +0000 (Sat, 23 Feb 2013)
Log Message:
-----------
code cleanup: bge - was converting float[] to MT_Vector's just to compare. use BLI_math instead.

Modified Paths:
--------------
    trunk/blender/source/gameengine/Rasterizer/CMakeLists.txt
    trunk/blender/source/gameengine/Rasterizer/RAS_TexVert.cpp

Modified: trunk/blender/source/gameengine/Rasterizer/CMakeLists.txt
===================================================================
--- trunk/blender/source/gameengine/Rasterizer/CMakeLists.txt	2013-02-23 01:33:47 UTC (rev 54773)
+++ trunk/blender/source/gameengine/Rasterizer/CMakeLists.txt	2013-02-23 01:57:56 UTC (rev 54774)
@@ -29,6 +29,7 @@
 	../Ketsji
 	../SceneGraph
 	../../blender/makesdna
+	../../blender/blenlib
 	../../blender/blenkernel
 	../../../intern/container
 	../../../intern/guardedalloc

Modified: trunk/blender/source/gameengine/Rasterizer/RAS_TexVert.cpp
===================================================================
--- trunk/blender/source/gameengine/Rasterizer/RAS_TexVert.cpp	2013-02-23 01:33:47 UTC (rev 54773)
+++ trunk/blender/source/gameengine/Rasterizer/RAS_TexVert.cpp	2013-02-23 01:57:56 UTC (rev 54774)
@@ -32,20 +32,21 @@
 
 #include "RAS_TexVert.h"
 #include "MT_Matrix4x4.h"
+#include "BLI_math.h"
 
 RAS_TexVert::RAS_TexVert(const MT_Point3& xyz,
-						 const MT_Point2 uvs[MAX_UNIT],
-						 const MT_Vector4& tangent,
-						 const unsigned int rgba,
-						 const MT_Vector3& normal,
-						 const bool flat,
-						 const unsigned int origindex)
+                         const MT_Point2 uvs[MAX_UNIT],
+                         const MT_Vector4& tangent,
+                         const unsigned int rgba,
+                         const MT_Vector3& normal,
+                         const bool flat,
+                         const unsigned int origindex)
 {
 	xyz.getValue(m_localxyz);
 	SetRGBA(rgba);
 	SetNormal(normal);
 	tangent.getValue(m_tangent);
-	m_flag = (flat)? FLAT: 0;
+	m_flag = (flat) ? FLAT: 0;
 	m_origindex = origindex;
 	m_unit = 2;
 	m_softBodyIndex = -1;
@@ -79,7 +80,7 @@
 
 void RAS_TexVert::SetXYZ(const float xyz[3])
 {
-	m_localxyz[0] = xyz[0]; m_localxyz[1] = xyz[1]; m_localxyz[2] = xyz[2];
+	copy_v3_v3(m_localxyz, xyz);
 }
 
 void RAS_TexVert::SetUV(int index, const MT_Point2& uv)
@@ -89,8 +90,7 @@
 
 void RAS_TexVert::SetUV(int index, const float uv[2])
 {
-	m_uvs[index][0] = uv[0];
-	m_uvs[index][1] = uv[1];
+	copy_v2_v2(m_uvs[index], uv);
 }
 
 void RAS_TexVert::SetRGBA(const unsigned int rgba)
@@ -106,7 +106,7 @@
 
 void RAS_TexVert::SetUnit(const unsigned int u)
 {
-	m_unit = u <= (unsigned int) MAX_UNIT ? u: (unsigned int)MAX_UNIT;
+	m_unit = (u <= (unsigned int) MAX_UNIT) ? u: (unsigned int)MAX_UNIT;
 }
 
 void RAS_TexVert::SetNormal(const MT_Vector3& normal)
@@ -123,19 +123,21 @@
 // compare two vertices, and return TRUE if both are almost identical (they can be shared)
 bool RAS_TexVert::closeTo(const RAS_TexVert* other)
 {
-	bool uv_match = true;
-	for (int i=0; i<MAX_UNIT; i++)
-		uv_match = uv_match && MT_fuzzyEqual(MT_Vector2(m_uvs[i]), MT_Vector2(other->m_uvs[i]));
+	const float eps = FLT_EPSILON;
+	for (int i = 0; i < MAX_UNIT; i++) {
+		if (!compare_v2v2(m_uvs[i], other->m_uvs[i], eps)) {
+			return false;
+		}
+	}
 
-	return (
-		/* m_flag == other->m_flag && */
-		/* at the moment the face only stores the smooth/flat setting so don't bother comparing it */
-		m_rgba == other->m_rgba &&
-		MT_fuzzyEqual(MT_Vector3(m_normal), MT_Vector3(other->m_normal)) &&
-		MT_fuzzyEqual(MT_Vector3(m_tangent), MT_Vector3(other->m_tangent)) &&
-		uv_match /* &&
-		MT_fuzzyEqual(MT_Vector3(m_localxyz), MT_Vector3(other->m_localxyz))*/);
-	/* don't bother comparing m_localxyz since we know there from the same vert */
+	return (/* m_flag == other->m_flag && */
+	        /* at the moment the face only stores the smooth/flat setting so don't bother comparing it */
+	        (m_rgba == other->m_rgba) &&
+	        compare_v3v3(m_normal, other->m_normal, eps) &&
+	        compare_v3v3(m_tangent, other->m_tangent, eps)
+	        /* don't bother comparing m_localxyz since we know there from the same vert */
+	        /* && compare_v3v3(m_localxyz, other->m_localxyz, eps))*/
+	        );
 }
 
 short RAS_TexVert::getFlag() const
@@ -151,9 +153,9 @@
 
 void RAS_TexVert::Transform(const MT_Matrix4x4& mat, const MT_Matrix4x4& nmat)
 {
-	SetXYZ((mat*MT_Vector4(m_localxyz[0], m_localxyz[1], m_localxyz[2], 1.0)).getValue());
-	SetNormal((nmat*MT_Vector4(m_normal[0], m_normal[1], m_normal[2], 1.0)).getValue());
-	SetTangent((nmat*MT_Vector4(m_tangent[0], m_tangent[1], m_tangent[2], 1.0)).getValue());
+	SetXYZ((mat * MT_Vector4(m_localxyz[0], m_localxyz[1], m_localxyz[2], 1.0)).getValue());
+	SetNormal((nmat * MT_Vector4(m_normal[0], m_normal[1], m_normal[2], 1.0)).getValue());
+	SetTangent((nmat * MT_Vector4(m_tangent[0], m_tangent[1], m_tangent[2], 1.0)).getValue());
 }
 
 void RAS_TexVert::TransformUV(int index, const MT_Matrix4x4& mat)




More information about the Bf-blender-cvs mailing list